@@ -44,6 +44,7 @@ def AssignSubtypes(tree):
   subtype_assigner = _SubtypeAssigner()
   subtype_assigner.Visit(tree)
 
+
 # Map tokens in argument lists to their respective subtype.
 _ARGLIST_TOKEN_TO_SUBTYPE = {
     '=': format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN,
@@ -63,38 +64,42 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
     # dictsetmaker ::= (test ':' test (comp_for |
     #                                   (',' test ':' test)* [','])) |
     #                  (test (comp_for | (',' test)* [',']))
+    for child in node.children:
+      self.Visit(child)
+
+    comp_for = False
     dict_maker = False
-    if len(node.children) > 1:
-      index = 0
-      while index < len(node.children):
-        if node.children[index].type != token.COMMENT:
-          break
-        index += 1
-      if index < len(node.children):
-        child = node.children[index + 1]
-        dict_maker = isinstance(child, pytree.Leaf) and child.value == ':'
-    last_was_colon = False
+
     for child in node.children:
       if pytree_utils.NodeName(child) == 'comp_for':
+        comp_for = True
         _AppendFirstLeafTokenSubtype(child,
                                      format_token.Subtype.DICT_SET_GENERATOR)
-      else:
+      elif pytree_utils.NodeName(child) in ('COLON', 'DOUBLESTAR'):
+        dict_maker = True
+
+    if not comp_for and dict_maker:
+      last_was_colon = False
+      for child in node.children:
         if dict_maker:
+          if pytree_utils.NodeName(child) == 'DOUBLESTAR':
+            _AppendFirstLeafTokenSubtype(child,
+                                         format_token.Subtype.KWARGS_STAR_STAR)
           if last_was_colon:
             if style.Get('INDENT_DICTIONARY_VALUE'):
               _InsertPseudoParentheses(child)
             else:
               _AppendFirstLeafTokenSubtype(
                   child, format_token.Subtype.DICTIONARY_VALUE)
-          elif (child is not None and
-                (isinstance(child, pytree.Node) or child.value not in '{:,')):
+          elif (child is not None and (isinstance(child, pytree.Node) or
+                                       (not child.value.startswith('#') and
+                                        child.value not in '{:,'))):
             # Mark the first leaf of a key entry as a DICTIONARY_KEY. We
             # normally want to split before them if the dictionary cannot exist
             # on a single line.
             _AppendFirstLeafTokenSubtype(child,
                                          format_token.Subtype.DICTIONARY_KEY)
-        last_was_colon = isinstance(child, pytree.Leaf) and child.value == ':'
-      self.Visit(child)
+        last_was_colon = pytree_utils.NodeName(child) == 'COLON'
 
   def Visit_expr_stmt(self, node):  # pylint: disable=invalid-name
     # expr_stmt ::= testlist_star_expr (augassign (yield_expr|testlist)
@@ -130,10 +135,12 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
     # comp_op ::= '<'|'>'|'=='|'>='|'<='|'<>'|'!='|'in'|'not in'|'is'|'is not'
     for child in node.children:
       self.Visit(child)
-      if (isinstance(child, pytree.Leaf) and child.value in {
-          '<', '>', '==', '>=', '<=', '<>', '!=', 'in', 'not in', 'is', 'is not'
-      }):
+      if (isinstance(child, pytree.Leaf) and
+          child.value in {'<', '>', '==', '>=', '<=', '<>', '!=', 'in', 'is'}):
         _AppendTokenSubtype(child, format_token.Subtype.BINARY_OPERATOR)
+      elif pytree_utils.NodeName(child) == 'comp_op':
+        for grandchild in child.children:
+          _AppendTokenSubtype(grandchild, format_token.Subtype.BINARY_OPERATOR)
 
   def Visit_star_expr(self, node):  # pylint: disable=invalid-name
     # star_expr ::= '*' expr
@@ -343,6 +350,18 @@ def _InsertPseudoParentheses(node):
   first = _GetFirstLeafNode(node)
   last = _GetLastLeafNode(node)
 
+  if first == last and first.type == token.COMMENT:
+    # A comment was inserted before the value, which is a pytree.Leaf.
+    # Encompass the dictionary's value into an ATOM node.
+    last = first.next_sibling
+    new_node = pytree.Node(syms.atom, [first.clone(), last.clone()])
+    node.replace(new_node)
+    node = new_node
+    last.remove()
+
+    first = _GetFirstLeafNode(node)
+    last = _GetLastLeafNode(node)
+
   lparen = pytree.Leaf(
       token.LPAR, u'(', context=('', (first.get_lineno(), first.column - 1)))
   last_lineno = last.get_lineno()
